LavueController Tango Class Attributes

LavueController Class Attributes
Name | Inherited | Abstract | Attr. type | R/W type | Data type | Level | Description
BeamCenterX | false | false | Scalar | READ_WRITE | Tango::DEV_DOUBLE | OPERATOR |
BeamCenterY | false | false | Scalar | READ_WRITE | Tango::DEV_DOUBLE | OPERATOR |
DetectorDistance | false | false | Scalar | READ_WRITE | Tango::DEV_DOUBLE | OPERATOR |
DetectorROIs | false | false | Scalar | READ_WRITE | Tango::DEV_STRING | EXPERT | json dictionary with detector ROIs, e.g. {\"pilatusroi1\": [[26, 15, 232, 65]], \"lambdarois\": [[54, 78, 102, 204], [10, 20, 40, 50]]}
DetectorROIsValues | false | false | Scalar | READ_WRITE | Tango::DEV_STRING | OPERATOR | json dictionary with detector ROIs values, e.g. {\"pilatusroi1\": [26.3], \"lambdarois\": [54.3, 434.30]]}
Energy | false | false | Scalar | READ_WRITE | Tango::DEV_DOUBLE | OPERATOR |
DetectorROIsParams | false | false | Scalar | READ_WRITE | Tango::DEV_STRING | OPERATOR | json dictionary with detector ROIs parameters, e.g. {\"transpose\": False, \"flip-lr\": True, \"flip-ud\": False}
LavueState | false | false | Scalar | READ_WRITE | Tango::DEV_STRING | EXPERT | json dictionary with lavue state configuration, e.g. {\``source\``: \``hidra\``, \``configuration\``: \``hasodet.desy.de\``}
PixelSizeX | false | false | Scalar | READ_WRITE | Tango::DEV_DOUBLE | OPERATOR | pixel x- size in micrometers
PixelSizeY | false | false | Scalar | READ_WRITE | Tango::DEV_DOUBLE | OPERATOR | pixel y- size in micrometers
ToolResults | false | false | Scalar | READ_WRITE | Tango::DEV_STRING | EXPERT | json dictionary with tool results

LavueController Class Dynamic Attributes
Name | Inherited | Abstract | Attr. type | R/W type | Data type | Level | Description
ScalarDynamicAttr | false | false | Scalar | READ | Tango::DEV_DOUBLE | OPERATOR |
SpectrumDynamicAttr | false | false | Spectrum | READ | Tango::DEV_DOUBLE | OPERATOR |
ROIsDynamicAttr | false | false | Spectrum | READ | Tango::DEV_DOUBLE | OPERATOR |